==> haskell-securemem-0.1.9-34-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-securemem.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: securemem
version: 0.1.9
id: securemem-0.1.9-3AHKIsUttOV3HUFAQP322o
key: securemem-0.1.9-3AHKIsUttOV3HUFAQP322o
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: vincent@snarc.org
stability: experimental
homepage: http://github.com/vincenthz/hs-securemem
synopsis: abstraction to an auto scrubbing and const time eq, memory chunk.
description:
    SecureMem is similar to ByteString, except that it provides a memory chunk that
    will be auto-scrubbed after it run out of scope.
category: Data
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
indefinite: False
exposed-modules:
    Data.SecureMem
abi: 6ece086433153391bb13e9bd4ffab6a1
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/securemem-0.1.9
library-dirs: /usr/lib/ghc-8.2.2/site-local/securemem-0.1.9
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/securemem-0.1.9
hs-libraries: HSsecuremem-0.1.9-3AHKIsUttOV3HUFAQP322o
depends:
    base-4.10.1.0 bytestring-0.10.8.2
    byteable-0.1.1-4PLPgH6a2E14oN7yL5y3oL
    memory-0.14.14-FiOA0zEQIqU9pMZGNyv72b ghc-prim-0.5.1.1
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             byteable-0.1.1-4PLPgH6a2E14oN7yL5y3oL=d7caed3dfdc2cc9400ff9a46cbe7296d
             memory-0.14.14-FiOA0zEQIqU9pMZGNyv72b=31288e97a1618db31ba2d3698d738018
             ghc-prim-0.5.1.1=84323a6edd008b04bf217464a4ccaf16
haddock-interfaces: /usr/share/doc/haskell-securemem/html/securemem.haddock
haddock-html: /usr/share/doc/haskell-securemem/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-securemem-0.1.9-36-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-securemem.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: securemem
version: 0.1.9
id: securemem-0.1.9-EWx3A9fC3Rk4WU5A4ddrwn
key: securemem-0.1.9-EWx3A9fC3Rk4WU5A4ddrwn
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: vincent@snarc.org
stability: experimental
homepage: http://github.com/vincenthz/hs-securemem
synopsis: abstraction to an auto scrubbing and const time eq, memory chunk.
description:
    SecureMem is similar to ByteString, except that it provides a memory chunk that
    will be auto-scrubbed after it run out of scope.
category: Data
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
indefinite: False
exposed-modules:
    Data.SecureMem
abi: 7e20b87c3add4420987e09cfba886507
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/securemem-0.1.9
library-dirs: /usr/lib/ghc-8.2.2/site-local/securemem-0.1.9
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/securemem-0.1.9
hs-libraries: HSsecuremem-0.1.9-EWx3A9fC3Rk4WU5A4ddrwn
depends:
    base-4.10.1.0 bytestring-0.10.8.2
    byteable-0.1.1-4PLPgH6a2E14oN7yL5y3oL
    memory-0.14.14-4o8zyRHIoSnHzCBHYQGHAV ghc-prim-0.5.1.1
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             byteable-0.1.1-4PLPgH6a2E14oN7yL5y3oL=d7caed3dfdc2cc9400ff9a46cbe7296d
             memory-0.14.14-4o8zyRHIoSnHzCBHYQGHAV=cd1266467377c3b0ef3fabb0cb06b2c3
             ghc-prim-0.5.1.1=84323a6edd008b04bf217464a4ccaf16
haddock-interfaces: /usr/share/doc/haskell-securemem/html/securemem.haddock
haddock-html: /usr/share/doc/haskell-securemem/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
